@@ -65,42 +65,43 @@ def solve_ls(
 
     Parameters
     ----------
-    R : numpy.ndarray, scipy.sparse.csc_matrix or cvxopt.spmatrix
+    R :
         Symmetric matrix of the cost function (most solvers require it to be
         definite).
-    s : numpy.ndarray
+    s :
         Vector term of the cost function.
-    G : numpy.ndarray, scipy.sparse.csc_matrix or cvxopt.spmatrix, optional
+    G :
         Linear inequality matrix.
-    h : numpy.ndarray, optional
+    h :
         Linear inequality vector.
-    A : numpy.ndarray, scipy.sparse.csc_matrix or cvxopt.spmatrix, optional
+    A :
         Linear equality matrix.
-    b : numpy.ndarray, optional
+    b :
         Linear equality vector.
-    lb: numpy.ndarray, scipy.sparse.csc_matrix or cvxopt.spmatrix, optional
+    lb:
         Lower bound constraint vector.
-    ub: numpy.ndarray, scipy.sparse.csc_matrix or cvxopt.spmatrix, optional
+    ub:
         Upper bound constraint vector.
-    W : numpy.ndarray, scipy.sparse.csc_matrix or cvxopt.spmatrix, optional
+    W :
         Definite symmetric weight matrix used to define the norm of the cost
         function. The standard L2 norm (W = Identity) is used by default.
-    solver : string, optional
-        Name of the QP solver, to choose in ``qpsolvers.available_solvers``.
-    initvals : numpy.ndarray, optional
+    solver :
+        Name of the QP solver, to choose in
+        :data:`qpsolvers.available_solvers`.
+    initvals :
         Vector of initial `x` values used to warm-start the solver.
-    sym_proj : bool, optional
+    sym_proj :
         Set to `True` when the `R` matrix provided is not symmetric.
-    verbose : bool, optional
+    verbose :
         Set to `True` to print out extra information.
 
     Returns
     -------
-    x : array or None
-        Optimal solution if found, None otherwise.
+    :
+        Optimal solution if found, otherwise ``None``.
 
-    Note
-    ----
+    Notes
+    -----
     Extra keyword arguments given to this function are forwarded to the
     underlying solvers. For example, OSQP has a setting `eps_abs` which we can
     provide by ``solve_ls(R, s, G, h, solver='osqp', eps_abs=1e-4)``.
