@@ -65,34 +65,38 @@ def ecos_solve_qp(
 
     Parameters
     ----------
-    P : numpy.ndarray
+    P :
         Primal quadratic cost matrix.
-    q : numpy.ndarray
+    q :
         Primal quadratic cost vector.
-    G : numpy.ndarray
+    G :
         Linear inequality constraint matrix.
-    h : numpy.ndarray
+    h :
         Linear inequality constraint vector.
-    A : numpy.ndarray, optional
+    A :
         Linear equality constraint matrix.
-    b : numpy.ndarray, optional
+    b :
         Linear equality constraint vector.
-    initvals : numpy.ndarray, optional
+    initvals :
         Warm-start guess vector (not used).
-    verbose : bool, optional
+    verbose :
         Set to `True` to print out extra information.
 
     Returns
     -------
-    x : numpy.ndarray, shape=(n,)
+    :
         Solution to the QP, if found, otherwise ``None``.
     """
     if initvals is not None:
         warn("note that warm-start values ignored by this wrapper")
     c_socp, G_socp, h_socp, dims = convert_to_socp(P, q, G, h)
     if A is not None:
-        A_socp = sparse.hstack([A, sparse.csc_matrix((A.shape[0], 1))], format="csc")
-        solution = solve(c_socp, G_socp, h_socp, dims, A_socp, b, verbose=verbose)
+        A_socp = sparse.hstack(
+            [A, sparse.csc_matrix((A.shape[0], 1))], format="csc"
+        )
+        solution = solve(
+            c_socp, G_socp, h_socp, dims, A_socp, b, verbose=verbose
+        )
     else:
         solution = solve(c_socp, G_socp, h_socp, dims, verbose=verbose)
     flag = solution["info"]["exitFlag"]
