@@ -75,32 +75,32 @@ def scs_solve_qp(
 
     Parameters
     ----------
-    P : numpy.ndarray, shape=(n, n)
+    P :
         Primal quadratic cost matrix.
-    q : numpy.ndarray, shape=(n,)
+    q :
         Primal quadratic cost vector.
-    G : numpy.ndarray, shape=(m, n)
+    G :
         Linear inequality constraint matrix.
-    h : numpy.ndarray, shape=(m,)
+    h :
         Linear inequality constraint vector.
-    A : numpy.ndarray, shape=(k, n), optional
+    A :
         Linear equality constraint matrix.
-    b : numpy.ndarray, shape=(k, n), optional
+    b :
         Linear equality constraint vector.
-    initvals : numpy.ndarray, shape=(n,), optional
+    initvals :
         Warm-start guess vector (not used).
-    verbose : bool, optional
+    verbose :
         Set to `True` to print out extra information.
-    eps : float, optional
+    eps :
         Convergence tolerange.
-    use_indirect: bool, optional
+    use_indirect:
         Solve linear systems either "directly" via a sparse LDL factorization
         or "indirectly" by means of a `conjugate gradient method
         <https://stanford.edu/~boyd/papers/pdf/scs_long.pdf>`_.
 
     Returns
     -------
-    x : numpy.ndarray, shape=(n,)
+    :
         Solution to the QP, if found, otherwise ``None``.
 
     Notes
@@ -118,10 +118,14 @@ def scs_solve_qp(
     if initvals is not None:
         warn("note that warm-start values ignored by this wrapper")
     c_socp, G_socp, h_socp, dims = convert_to_socp(P, q, G, h)
-    kwargs.update({"eps": eps, "use_indirect": use_indirect, "verbose": verbose})
+    kwargs.update(
+        {"eps": eps, "use_indirect": use_indirect, "verbose": verbose}
+    )
     if A is not None and b is not None:
         dims["f"] = A.shape[0]  # number of equality constraints
-        A_socp = sparse.hstack([A, sparse.csc_matrix((A.shape[0], 1))], format="csc")
+        A_socp = sparse.hstack(
+            [A, sparse.csc_matrix((A.shape[0], 1))], format="csc"
+        )
         A_scs = sparse.vstack([A_socp, G_socp], format="csc")
         b_scs = hstack([b, h_socp])
         data = {"A": A_scs, "b": b_scs, "c": c_socp}
@@ -131,7 +135,9 @@ def scs_solve_qp(
         solution = solve(data, dims, **kwargs)
     status_val = solution["info"]["statusVal"]
     if status_val != 1:
-        warn(f"SCS returned {status_val}: {__status_val_meaning__[status_val]}")
+        warn(
+            f"SCS returned {status_val}: {__status_val_meaning__[status_val]}"
+        )
         if status_val != 2:
             # solution is not inaccurate, so the optimization failed
             return None
