@@ -43,17 +43,17 @@ class TestQuadprog(unittest.TestCase):
 
         Returns
         -------
-        P : numpy.ndarray
+        P :
             Symmetric quadratic-cost matrix .
-        q : numpy.ndarray
+        q :
             Quadratic-cost vector.
-        G : numpy.ndarray
+        G :
             Linear inequality matrix.
-        h : numpy.ndarray
+        h :
             Linear inequality vector.
-        A : numpy.ndarray, scipy.sparse.csc_matrix or cvxopt.spmatrix
+        A :
             Linear equality matrix.
-        b : numpy.ndarray
+        b :
             Linear equality vector.
         """
         M = array([[1.0, 2.0, 0.0], [-8.0, 3.0, 2.0], [0.0, 1.0, 1.0]])
